.. only:: html

    ============
    Bibliography
    ============

    The following is a non-comprehensive list of publications that were
    used as a theoretical foundation for implementing the Diofant.

.. bibliography:: sources.bib
    :cited:
